#Anne Inkenhaag 2021
#Script to plot the relation between Lx and LOIII from Heckman+2005 and plot our measurement from PTF09axc
import numpy as np
import matplotlib.pyplot as plt

#our measurement, see paper on how we derived this
datapoint = np.array([42.9, 39.67])

#create the lines for the Heckman+2005 relation including uncertainty regions
Lx=np.array([40, 44])
Lo3 = Lx - 2.15

sig1_up = Lx - 1.64
sig1_low = Lx - 2.66

sig2_up = Lx - 1.13
sig2_low = Lx - 3.17

sig3_up = Lx - 0.62
sig3_low = Lx -3.68

#plot the relation and the confidence intervals and overplot our data point
plt.fill_between(Lx, sig3_low, sig3_up, color='lightgrey', linewidth=0.0, label=r'99$\%$ confidence interval')
plt.fill_between(Lx, sig2_low, sig2_up, color='darkgrey', linewidth=0.0, label=r'95$\%$ confidence interval')
plt.fill_between(Lx, sig1_low, sig1_up, color='dimgrey', linewidth=0.0, label=r'68$\%$ confidence interval')
plt.plot(Lx, Lo3, 'k', label='relation from Heckman+2005')
plt.plot(datapoint[0], datapoint[1], 'rs', label=r'SDSSJ1453 2$\sigma$ upper limit')
plt.errorbar(datapoint[0], datapoint[1], yerr=.5, uplims=True, alpha=0.5, ecolor='r')
plt.xlim(40, 44)
plt.xlabel(r"log(L$_\mathrm{X}$ (erg s$^{-1}$))", fontsize='x-large')
plt.ylabel(r"log(L$_{[\mathrm{O III}]}$ (erg s$^{-1}$))", fontsize='x-large')
plt.legend(loc='upper left')
plt.tight_layout()
plt.savefig("Heckman_rel.pdf", dpi=600)
plt.show()
