## PTF09axc

Contents of this directory:

``data.zip``: contains the files:
   - ``PTF09axc.fits`` the original data in fits format to use with pPXF
   - ``PTF09axc_fluxcal_ave.dat`` the original data in ascii format which includes the error on the flux in the third column
   - ``PTF09axc_nosky_ave.dat`` the original data without the sky background subtracted in ascii format, this is needed do derive the upper limit on the [OIII]5007AA line

``rel_error.py``: creates the relative error on the flux of the original data to use in the ``multi_gauss_lmfit`` scripts

``ppxf_PTF09axc.py``: uses pPXF to find the best fitting stellar population to the galaxy 

``BPT_diagram.py``: creates BPT-diagrams

``PTF09axc_lines.txt``: example of collected output of the collected outputs of the line fitting scripts in the correct format to use with ``BPT_diagram.py``

``multi_gauss_lmfit_{..}.py``: fits Gaussian curves to emission lines

``Heckmanrel_plot.py``: creates a plot with the relation from [Heckman et al (2005)](https://ui.adsabs.harvard.edu/abs/2005ApJ...634..161H) and our data point 

## Notes on usage

1. To find the best fitting stellar population using pPXF run:
	``python ppxf_PTF09axc.py``, this will create three ``.dat`` files ``host_bestfit_PTF09axc``, ``PTF09axc_sub`` and ``PTF09axc_sub_norm`` as well as _Figure 3_ in the paper ``host_bestfit_PTF09axc.pdf``

2. To create the file with relative errors run:
	``python rel_error.py PTF09axc.fits PTF09axc_fluxcal_ave.dat``, this will create the file ``rel_error_PTF09axc.dat`` 

3. To find the flux in the emission lines run:
	``python multi_gauss_lmfit_Halpha_NII.py PTF09axc_sub.dat rel_error_PTF09axc.dat > HalphaNII_lines.txt``, this will create a ``.txt`` file containing the fitting output as well as _Figure A2 (c)_ ``fit_PTF09axc_sub.dat_Halpha_NII_errorbars.pdf``
	``python multi_gauss_lmfit_Hbeta.py PTF09axc_sub.dat rel_error_PTF09axc.dat > Hbeta_lines.txt``, this will create a ``.txt`` file containing the fitting output as well as _Figure A2 (a)_ ``fit_PTF09axc_sub.dat_Hbeta_errorbars.pdf`` 

4. To find the upper limit on the OIII doublet run:
	``python multi_gauss_lmfit_OIII_UL.py PTF09axc_nosky_ave.dat > OIII_UL_lines.txt``, this will create a ``.txt`` file containing the fitting output as well as _Figure A2 (b)_ ``fit_PTF09axc_sub.dat_OIII_UL_errorbars.pdf``

5. From the ``.txt`` files created in step 3 and 4, create a file called ``PTF09axc_lines.txt`` that contains the output of the fitting procedures with line names (``Halpha_broad/narrow``, ``NII_6548/84``, ``OII_5007/4959``) in stead of ``line1, line2``.The information needed is underneath the output line containing ``#line	 	WV 	 	 dWV 	 FWHM(km/s) 	 dFWHM(km/s) 	 EW 	 	dEW 	 	flux 	 	 dflux``. Copy all columns into the new file.
Our version of this file is present in the directory as ``PTF09axc_lines.txt`` which should be the exact same, but it is good to check. The results of the fitting procedure are the results in _Table A1_.

6. To create the BPT diagram run:
	``python BPT_diagram.py``, this will create ``PTF09axc_BPT.pdf`` which is _Figure 4_.

7. To create _Figure 6_ run:
	``python Heckmanrel_plot.py`` which will create ``Heckman_rel.pdf`` which is _Figure 6_.

