#Anne Inkenhaag 2020
#script to calculate relative error for the flux of a spectrum to use in the multi_gauss_lmfit scripts

import numpy as np
import sys
from astropy.io import fits
from astropy.io import ascii
import ppxf.ppxf_util as util

#read in the flux from a fits file and read in the error on the flux from the ascii file of the same data
file = sys.argv[1]
hdu = fits.open(file)
gal_flux = hdu[0].data
gal_error = np.loadtxt(sys.argv[2], usecols=2, unpack=True)
h1 = hdu[0].header

#use the data and the header to create a (redshift corrected) wavelenth array with the same values as pPXF returns and the corresponding relative errors in the flux for those wavelengths
z = 0.1153 #this is the redshift obtained from the pPXF fitting 
lamRange1 = h1['CRVAL1']/(1+z) + np.array([0., h1['CD1_1']*(h1['NAXIS1'] - 1)])/(1+z)
error, logLam1, velscale = util.log_rebin(lamRange1, gal_error)
flux, logLam1, velscale = util.log_rebin(lamRange1, gal_flux)

#remove the entries at the beginning and the end of the array that are 0
mask = ((error>0)&(flux>0))

rel_error = error[mask]/flux[mask]
lam1 = np.exp(logLam1[mask])

#write out a file with two columns, one for the wavelength (#lam1) and one for the relative error in the flux (#rel_error)
ascii.write([lam1, rel_error], 'rel_error_'+file.split('.')[0]+'.dat', names=['#lam1', '#rel_error'], overwrite=True)
